@@ -132,7 +132,7 @@ def generate_zip(server_address: str = None, server_filename: str = "pubserver.p
 
 
 class AtakOfTheCerts:
-    def __init__(self, pwd: str = "atakatak") -> None:
+    def __init__(self, pwd: str = MainConfig.password) -> None:
         """
         :param pwd: String based password used to secure the p12 files generated, defaults to atakatak
         """
