@@ -25,6 +25,7 @@ loggingConstants = LoggingConstants()
 logger = CreateLoggerController("FTS").getLogger()
 
 
+# noinspection PyUnresolvedReferences
 class FTS:
 
     def __init__(self):
@@ -495,26 +496,33 @@ class FTS:
     def checkPipes(self):
         try:
             for pipe in self.FilterGroup.sources:
-                data = AddDataToCoTList().recv(pipe)
+                try:
+                    data = AddDataToCoTList().recv(pipe)
+                except Exception as e:
+                    logger.error('get pipe data failed '+str(e))
+                    continue
                 #this runs in the event a new client has connected
-                if isinstance(data, list):
-                    AddDataToCoTList().send(self.FilterGroup.receivers, data[0])
-                    for client in self.clientArray:
-                        AddDataToCoTList().send(self.FilterGroup.receivers, client)
-                # this runs in all other cases in which data is received
-                elif data != 0 and data is not None:
-                    try:
-                        print('data received in FTS ' + str(data.xmlString))
-                    except:
+                try:
+                    if isinstance(data, list):
+                        AddDataToCoTList().send(self.FilterGroup.receivers, data[0])
+                        for client in self.clientArray:
+                            AddDataToCoTList().send(self.FilterGroup.receivers, client)
+                    # this runs in all other cases in which data is received
+                    elif data != 0 and data is not None:
+                        try:
+                            print('data received in FTS ' + str(data.xmlString))
+                        except:
+                            pass
+                        AddDataToCoTList().send(self.FilterGroup.receivers, data)
+                    # this runs when a timeout is triggered
+                    else:
                         pass
-                    AddDataToCoTList().send(self.FilterGroup.receivers, data)
-                # this runs when a timeout is triggered
-                else:
-                    pass
+                except Exception as e:
+                    logger.error('processing received connection data failed '+ str(e))
         except Exception as e:
             pass
 
-    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, SSLDataPackagePort, SSLDataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart, firstStart = False):
+    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, SSLDataPackagePort, SSLDataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart, firstStart = False, UI="False"):
         try:
             self.FTSServiceStartupConfigObject.RestAPIService.RestAPIServiceStatus = 'start'
             self.FTSServiceStartupConfigObject.RestAPIService.RestAPIServicePort = RestAPIPort
@@ -560,16 +568,29 @@ class FTS:
 
                 self.start_all(StartupObject)
 
-
             while True:
-                self.checkPipes()
-                self.clientArray = self.receive_data_froCoT_service_thread(self.ClientDataPipe, self.clientArray)
-                self.clientArray = self.receive_data_froCoT_service_thread(self.SSLClientDataPipe, self.clientArray)
-
+                try:
+                    self.checkPipes()
+                except Exception as e:
+                    logger.error("error in core FTS process Data Pipe " + str(e))
+                try:
+                    self.clientArray = self.receive_data_froCoT_service_thread(self.ClientDataPipe, self.clientArray)
+                except Exception as e:
+                    logger.error("error thrown receiving clients from tcp CoT pipe " + str(e))
+                try:
+                    self.clientArray = self.receive_data_froCoT_service_thread(self.SSLClientDataPipe, self.clientArray)
+                except Exception as e:
+                    logger.error("error thrown receiving clients from SSL CoT pipe " + str(e))
         except Exception as e:
             logger.error('exception in the startup of FTS ' + str(e))
 
 if __name__ == "__main__":
+    """import importlib
+    conf = importlib.import_module("FreeTAKServer-UI")
+    FreeTAKServerUI = importlib.import_module("FreeTAKServer-UI.app", "run")
+    y = FreeTAKServerUI.create_app()
+    UIProc = multiprocessing.Process(target=FreeTAKServerUI.app, args=())
+    UIProc.start()"""
     try:
         parser = argparse.ArgumentParser(description=OrchestratorConstants().FULLDESC)
         parser.add_argument('-CoTPort', type=int, help=OrchestratorConstants().COTPORTDESC,
@@ -592,10 +613,11 @@ if __name__ == "__main__":
                             default=FTSObj().RestAPIService.RestAPIServicePort)
         parser.add_argument('-RestAPIIP', type=str, help=OrchestratorConstants().APIPORTDESC,
                             default=FTSObj().RestAPIService.RestAPIServiceIP)
-        parser.add_argument('-AutoStart', type=str, help='wether or not you want all services to start or only the root service and the RestAPI service', default='True')
+        parser.add_argument('-AutoStart', type=str, help='whether or not you want all services to start or only the root service and the RestAPI service', default='True')
+        parser.add_argument('-UI', type=str, help="set to true if you would like to start UI on server startup")
         args = parser.parse_args()
         AtakOfTheCerts().bake_startup()
         CreateStartupFilesController()
-        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.SSLDataPackagePort, args.SSLDataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart, True)
+        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.SSLDataPackagePort, args.SSLDataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart, True, args.UI)
     except Exception as e:
         print(e)
\ No newline at end of file
